--[[
Name: Prat_Clear
Revision: $Revision:  r24999$
Author(s): Fin (fin@instinct.org)
Website: http://www.wowace.com/files/index.php?path=Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#Clear
Subversion: http://svn.wowace.com/wowace/trunk/Prat/
Discussions: http://groups.google.com/group/wow-prat
Issues and feature requests: http://code.google.com/p/prat/issues/list
Description:  Adds a /clear (or /cls) command that clears the current chat frame. (default=off).
Dependencies: Prat
]]

-- set prat module name
local PRAT_MODULE = Prat:RequestModuleName("Clear")

-- define localized strings
local L = AceLibrary("AceLocale-2.2"):new(PRAT_MODULE)

L:RegisterTranslations("enUS", function() return {
    ["Clear"] = true,

    ["Adds a /clear (or /cls) command that clears the current frame"] = true,
    ["Clears the current chat frame"] = true,
} end)

-- L:RegisterTranslations("deDE", function() return {
--     ["Clear"] = "",
-- } end)

-- L:RegisterTranslations("frFR", function() return {
--     ["Clear"] = "",
-- } end)
-- L:RegisterTranslations("esES", function() return {
--     ["Clear"] = "",
-- } end)

-- L:RegisterTranslations("koKR", function() return {
--     ["Clear"] = "",
-- } end)

-- L:RegisterTranslations("zhCN", function() return {
--     ["Clear"] = "",
-- } end)

-- L:RegisterTranslations("zhTW", function() return {
--     ["Clear"] = "",
-- } end)

-- get prat module categories
local cat = Prat.Categories

-- create prat module

Prat_Clear = Prat:NewModule(PRAT_MODULE)
Prat_Clear.revision = tonumber(string.sub("$Revision:  24999 $", 12, -3))

-- define key module values
Prat_Clear.moduleName = L["Clear"] 	-- module name, eg "ExampleMod"
-- !!
Prat_Clear.moduleDesc = L["Adds a /clear (or /cls) command that clears the current frame"] 	-- module description, eg "An example of a Prat 2 mod"

Prat_Clear.consoleName = string.lower(Prat_Clear.moduleName)
Prat_Clear.guiName = Prat_Clear.moduleName

-- !!
Prat_Clear.Categories = { cat.FRAME, cat.BEHAVIOUR }	-- categories in which the module will show up in the listing, eg "{ cat.DEV, cat.INFO }"
				-- list here: http://groups-beta.google.com/group/wow-prat/web/prat-categories


-- define the default db values
-- !!
Prat_Clear.defaultDB = {
    on = false,
}

-- build the options menu using prat templates
Prat_Clear.toggleOptions = { }

--[[------------------------------------------------
    Module Event Functions
------------------------------------------------]]--

local slashcmds = {
	'/clear',
	'/cls',
	}

-- things to do when the module is enabled
function Prat_Clear:OnModuleEnable()
	-- self:RegisterEvent("")
	local cmdopts = {
		name	= L['Clear'],
		desc	= L['Clears the current chat frame'],
		type	= "execute",
		func	= function() Prat_Clear:clear() end,
		}

	Prat:RegisterChatCommand(slashcmds, cmdopts, nil, 'PRAT_CLEAR');
end

-- things to do when the module is disabled
function Prat_Clear:OnModuleDisable()
    -- unregister events
    self:UnregisterAllEvents()
    
    -- for k, v in pairs(SlashCmdList) do
    
    -- should also remove the slash comands - not 
end

--[[------------------------------------------------
    Core Functions
------------------------------------------------]]--

-- things do stuff here


function Prat_Clear:clear()
	if self.db.profile.on then SELECTED_CHAT_FRAME:Clear(); end
end